# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatible_product_dto import CompatibleProductDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibleProductDto(unittest.TestCase):
    """CompatibleProductDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibleProductDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatible_product_dto.CompatibleProductDto()  # noqa: E501
        if include_optional :
            return CompatibleProductDto(
                id = 'fc1058e6-a901-4b58-be4d-3d7e1368f63e', 
                text = 'AUDI A6 (4G2, 4GC, C7) 2014/09-2018/09 3.0 TDI quattro 326KM/240kW', 
                group = allegro_api.models.compatible_product_dto_group.CompatibleProductDto_group(
                    id = '19d71c872aa6c78663876a7e7bc7776d', ), 
                attributes = [{"id":"BRAND","values":["AUDI"]}]
            )
        else :
            return CompatibleProductDto(
        )

    def testCompatibleProductDto(self):
        """Test CompatibleProductDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
