# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatible_products_list_dto import CompatibleProductsListDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibleProductsListDto(unittest.TestCase):
    """CompatibleProductsListDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibleProductsListDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatible_products_list_dto.CompatibleProductsListDto()  # noqa: E501
        if include_optional :
            return CompatibleProductsListDto(
                compatible_products = [{"id":"fc1058e6-a901-4b58-be4d-3d7e1368f63e","text":"AUDI A6 (4G2, 4GC, C7) 2014/09-2018/09 3.0 TDI quattro 326KM/240kW","group":{"id":"19d71c872aa6c78663876a7e7bc7776d"},"attributes":[{"id":"POWER_KW","values":["240"]},{"id":"MODEL_FROM","values":["2010/11"]},{"id":"BRAND","values":["AUDI"]},{"id":"POWER_HP","values":["326"]},{"id":"MODEL_TO","values":["2018/09"]},{"id":"ENGINE_CODE","values":["CVUB"]},{"id":"K_TYP_NR","values":["108441"]},{"id":"VERSION_FROM","values":["2014/09"]},{"id":"VERSION_TO","values":["2018/09"]},{"id":"MODEL","values":["A6 (4G2, 4GC, C7)"]},{"id":"BODY","values":["sedan"]},{"id":"TYPE","values":["3.0 TDI quattro"]}]}], 
                count = 1, 
                total_count = 1448
            )
        else :
            return CompatibleProductsListDto(
        )

    def testCompatibleProductsListDto(self):
        """Test CompatibleProductsListDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
