# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class BadgeApplicationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'campaign': 'BadgeApplicationCampaign',
        'offer': 'BadgeApplicationOffer',
        'prices': 'BadgeApplicationPrices',
        'purchase_constraints': 'BadgeApplicationPurchaseConstraints'
    }

    attribute_map = {
        'campaign': 'campaign',
        'offer': 'offer',
        'prices': 'prices',
        'purchase_constraints': 'purchaseConstraints'
    }

    def __init__(self, campaign=None, offer=None, prices=None, purchase_constraints=None, local_vars_configuration=None):  # noqa: E501
        """BadgeApplicationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._campaign = None
        self._offer = None
        self._prices = None
        self._purchase_constraints = None
        self.discriminator = None

        self.campaign = campaign
        self.offer = offer
        if prices is not None:
            self.prices = prices
        if purchase_constraints is not None:
            self.purchase_constraints = purchase_constraints

    @property
    def campaign(self):
        """Gets the campaign of this BadgeApplicationRequest.  # noqa: E501


        :return: The campaign of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationCampaign
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """Sets the campaign of this BadgeApplicationRequest.


        :param campaign: The campaign of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationCampaign
        """
        if self.local_vars_configuration.client_side_validation and campaign is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign`, must not be `None`")  # noqa: E501

        self._campaign = campaign

    @property
    def offer(self):
        """Gets the offer of this BadgeApplicationRequest.  # noqa: E501


        :return: The offer of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationOffer
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """Sets the offer of this BadgeApplicationRequest.


        :param offer: The offer of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationOffer
        """
        if self.local_vars_configuration.client_side_validation and offer is None:  # noqa: E501
            raise ValueError("Invalid value for `offer`, must not be `None`")  # noqa: E501

        self._offer = offer

    @property
    def prices(self):
        """Gets the prices of this BadgeApplicationRequest.  # noqa: E501


        :return: The prices of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationPrices
        """
        return self._prices

    @prices.setter
    def prices(self, prices):
        """Sets the prices of this BadgeApplicationRequest.


        :param prices: The prices of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationPrices
        """

        self._prices = prices

    @property
    def purchase_constraints(self):
        """Gets the purchase_constraints of this BadgeApplicationRequest.  # noqa: E501


        :return: The purchase_constraints of this BadgeApplicationRequest.  # noqa: E501
        :rtype: BadgeApplicationPurchaseConstraints
        """
        return self._purchase_constraints

    @purchase_constraints.setter
    def purchase_constraints(self, purchase_constraints):
        """Sets the purchase_constraints of this BadgeApplicationRequest.


        :param purchase_constraints: The purchase_constraints of this BadgeApplicationRequest.  # noqa: E501
        :type: BadgeApplicationPurchaseConstraints
        """

        self._purchase_constraints = purchase_constraints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BadgeApplicationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BadgeApplicationRequest):
            return True

        return self.to_dict() != other.to_dict()
