# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_shipping_rates import OfferShippingRates  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferShippingRates(unittest.TestCase):
    """OfferShippingRates unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferShippingRates
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_shipping_rates.OfferShippingRates()  # noqa: E501
        if include_optional :
            return OfferShippingRates(
                rates = [
                    allegro_api.models.shipping_rate.ShippingRate(
                        delivery_method = allegro_api.models.shipping_rate_delivery_method.ShippingRate_deliveryMethod(
                            id = '0', ), 
                        max_quantity_per_package = 1, 
                        first_item_rate = allegro_api.models.shipping_rate_first_item_rate.ShippingRate_firstItemRate(
                            amount = '0', 
                            currency = '0', ), 
                        next_item_rate = allegro_api.models.shipping_rate_next_item_rate.ShippingRate_nextItemRate(
                            amount = '0', 
                            currency = '0', ), 
                        shipping_time = allegro_api.models.shipping_rate_shipping_time.ShippingRate_shippingTime(
                            from = '0', 
                            to = '0', ), )
                    ]
            )
        else :
            return OfferShippingRates(
        )

    def testOfferShippingRates(self):
        """Test OfferShippingRates"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
