# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ModificationPromotion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bold': 'bool',
        'department_page': 'bool',
        'emphasized': 'bool',
        'emphasized_highlight_bold_package': 'bool',
        'highlight': 'bool'
    }

    attribute_map = {
        'bold': 'bold',
        'department_page': 'departmentPage',
        'emphasized': 'emphasized',
        'emphasized_highlight_bold_package': 'emphasizedHighlightBoldPackage',
        'highlight': 'highlight'
    }

    def __init__(self, bold=None, department_page=None, emphasized=None, emphasized_highlight_bold_package=None, highlight=None, local_vars_configuration=None):  # noqa: E501
        """ModificationPromotion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bold = None
        self._department_page = None
        self._emphasized = None
        self._emphasized_highlight_bold_package = None
        self._highlight = None
        self.discriminator = None

        if bold is not None:
            self.bold = bold
        if department_page is not None:
            self.department_page = department_page
        if emphasized is not None:
            self.emphasized = emphasized
        if emphasized_highlight_bold_package is not None:
            self.emphasized_highlight_bold_package = emphasized_highlight_bold_package
        if highlight is not None:
            self.highlight = highlight

    @property
    def bold(self):
        """Gets the bold of this ModificationPromotion.  # noqa: E501

        Bold flag: true, false, null  # noqa: E501

        :return: The bold of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this ModificationPromotion.

        Bold flag: true, false, null  # noqa: E501

        :param bold: The bold of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._bold = bold

    @property
    def department_page(self):
        """Gets the department_page of this ModificationPromotion.  # noqa: E501

        DepartmentPage flag: true, false, null  # noqa: E501

        :return: The department_page of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._department_page

    @department_page.setter
    def department_page(self, department_page):
        """Sets the department_page of this ModificationPromotion.

        DepartmentPage flag: true, false, null  # noqa: E501

        :param department_page: The department_page of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._department_page = department_page

    @property
    def emphasized(self):
        """Gets the emphasized of this ModificationPromotion.  # noqa: E501

        Emphasized flag: true, false, null  # noqa: E501

        :return: The emphasized of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized

    @emphasized.setter
    def emphasized(self, emphasized):
        """Sets the emphasized of this ModificationPromotion.

        Emphasized flag: true, false, null  # noqa: E501

        :param emphasized: The emphasized of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._emphasized = emphasized

    @property
    def emphasized_highlight_bold_package(self):
        """Gets the emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501

        EmphasizedHighlightBoldPackage flag: true, false, null  # noqa: E501

        :return: The emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._emphasized_highlight_bold_package

    @emphasized_highlight_bold_package.setter
    def emphasized_highlight_bold_package(self, emphasized_highlight_bold_package):
        """Sets the emphasized_highlight_bold_package of this ModificationPromotion.

        EmphasizedHighlightBoldPackage flag: true, false, null  # noqa: E501

        :param emphasized_highlight_bold_package: The emphasized_highlight_bold_package of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._emphasized_highlight_bold_package = emphasized_highlight_bold_package

    @property
    def highlight(self):
        """Gets the highlight of this ModificationPromotion.  # noqa: E501

        Highlight flag: true, false, null  # noqa: E501

        :return: The highlight of this ModificationPromotion.  # noqa: E501
        :rtype: bool
        """
        return self._highlight

    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this ModificationPromotion.

        Highlight flag: true, false, null  # noqa: E501

        :param highlight: The highlight of this ModificationPromotion.  # noqa: E501
        :type: bool
        """

        self._highlight = highlight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModificationPromotion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModificationPromotion):
            return True

        return self.to_dict() != other.to_dict()
