# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.classifieds_api import ClassifiedsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestClassifiedsApi(unittest.TestCase):
    """ClassifiedsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.classifieds_api.ClassifiedsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_classified_packages_using_put(self):
        """Test case for assign_classified_packages_using_put

        Assign packages to a classified  # noqa: E501
        """
        pass

    def test_get_classified_package_configuration_using_get(self):
        """Test case for get_classified_package_configuration_using_get

        Get the configuration of a package  # noqa: E501
        """
        pass

    def test_get_classified_package_configurations_for_category_using_get(self):
        """Test case for get_classified_package_configurations_for_category_using_get

        Get configurations of packages  # noqa: E501
        """
        pass

    def test_get_classified_packages_using_get(self):
        """Test case for get_classified_packages_using_get

        Get classified packages assigned to an offer  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
