# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.public_tables_dto import PublicTablesDto  # noqa: E501
from allegro_api.rest import ApiException

class TestPublicTablesDto(unittest.TestCase):
    """PublicTablesDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PublicTablesDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.public_tables_dto.PublicTablesDto()  # noqa: E501
        if include_optional :
            return PublicTablesDto(
                tables = [
                    allegro_api.models.public_table_dto.PublicTableDto(
                        headers = [
                            allegro_api.models.header.Header(
                                name = '0', )
                            ], 
                        id = '0', 
                        image = allegro_api.models.public_table_image_dto.PublicTableImageDto(
                            captions = [
                                allegro_api.models.caption.Caption(
                                    index = '0', 
                                    value = '0', )
                                ], 
                            url = '0', ), 
                        name = '0', 
                        orientation = 'HORIZONTAL', 
                        values = [
                            allegro_api.models.cells.Cells(
                                cells = [
                                    '0'
                                    ], )
                            ], )
                    ]
            )
        else :
            return PublicTablesDto(
                tables = [
                    allegro_api.models.public_table_dto.PublicTableDto(
                        headers = [
                            allegro_api.models.header.Header(
                                name = '0', )
                            ], 
                        id = '0', 
                        image = allegro_api.models.public_table_image_dto.PublicTableImageDto(
                            captions = [
                                allegro_api.models.caption.Caption(
                                    index = '0', 
                                    value = '0', )
                                ], 
                            url = '0', ), 
                        name = '0', 
                        orientation = 'HORIZONTAL', 
                        values = [
                            allegro_api.models.cells.Cells(
                                cells = [
                                    '0'
                                    ], )
                            ], )
                    ],
        )

    def testPublicTablesDto(self):
        """Test PublicTablesDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
