# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_selling_mode import OfferSellingMode  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferSellingMode(unittest.TestCase):
    """OfferSellingMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferSellingMode
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_selling_mode.OfferSellingMode()  # noqa: E501
        if include_optional :
            return OfferSellingMode(
                format = 'BUY_NOW', 
                price = allegro_api.models.offer_price.OfferPrice(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                fixed_price = allegro_api.models.offer_fixed_price.OfferFixedPrice(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                popularity = 38, 
                bid_count = 12
            )
        else :
            return OfferSellingMode(
        )

    def testOfferSellingMode(self):
        """Test OfferSellingMode"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
