# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.contacts_api import ContactsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestContactsApi(unittest.TestCase):
    """ContactsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.contacts_api.ContactsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_contact_using_post(self):
        """Test case for create_contact_using_post

        Create a new contact  # noqa: E501
        """
        pass

    def test_get_contact_using_get(self):
        """Test case for get_contact_using_get

        Get contact details  # noqa: E501
        """
        pass

    def test_get_list_of_contacts_using_get(self):
        """Test case for get_list_of_contacts_using_get

        Get the user's contacts  # noqa: E501
        """
        pass

    def test_modify_contact_using_put(self):
        """Test case for modify_contact_using_put

        Modify contact details  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
