# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.batch_offer_modification_api import BatchOfferModificationApi  # noqa: E501
from allegro_api.rest import ApiException


class TestBatchOfferModificationApi(unittest.TestCase):
    """BatchOfferModificationApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.batch_offer_modification_api.BatchOfferModificationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_general_report_using_get(self):
        """Test case for get_general_report_using_get

        Modification command summary  # noqa: E501
        """
        pass

    def test_get_price_modification_command_status_using_get(self):
        """Test case for get_price_modification_command_status_using_get

        Change price command summary  # noqa: E501
        """
        pass

    def test_get_price_modification_command_tasks_statuses_using_get(self):
        """Test case for get_price_modification_command_tasks_statuses_using_get

        Change price command detailed report  # noqa: E501
        """
        pass

    def test_get_quantity_modification_command_status_using_get(self):
        """Test case for get_quantity_modification_command_status_using_get

        Change quantity command summary  # noqa: E501
        """
        pass

    def test_get_quantity_modification_command_tasks_statuses_using_get(self):
        """Test case for get_quantity_modification_command_tasks_statuses_using_get

        Change quantity command detailed report  # noqa: E501
        """
        pass

    def test_get_tasks_using_get(self):
        """Test case for get_tasks_using_get

        Modification command detailed report  # noqa: E501
        """
        pass

    def test_modification_command_using_put(self):
        """Test case for modification_command_using_put

        Batch offer modification  # noqa: E501
        """
        pass

    def test_price_modification_command_using_put(self):
        """Test case for price_modification_command_using_put

        Batch offer price modification  # noqa: E501
        """
        pass

    def test_quantity_modification_command_using_put(self):
        """Test case for quantity_modification_command_using_put

        Batch offer quantity modification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
