# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.command_task import CommandTask  # noqa: E501
from allegro_api.rest import ApiException

class TestCommandTask(unittest.TestCase):
    """CommandTask unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CommandTask
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.command_task.CommandTask()  # noqa: E501
        if include_optional :
            return CommandTask(
                field = '0', 
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                message = '0', 
                offer = allegro_api.models.offer_id.OfferId(
                    id = '0', ), 
                scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                status = '0', 
                errors = [
                    allegro_api.models.error.Error(
                        code = 'NotAcceptableException', 
                        details = '0', 
                        message = 'Not acceptable representation requested. Please check 'Accept' request header', 
                        path = '0', 
                        user_message = 'The request contains incorrect data. Contact the author of the application.', )
                    ]
            )
        else :
            return CommandTask(
        )

    def testCommandTask(self):
        """Test CommandTask"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
