# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class AdditionalServicesGroupResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_services': 'list[AdditionalServiceResponse]',
        'created_at': 'datetime',
        'id': 'str',
        'updated_at': 'datetime',
        'name': 'str',
        'seller': 'Reference'
    }

    attribute_map = {
        'additional_services': 'additionalServices',
        'created_at': 'createdAt',
        'id': 'id',
        'updated_at': 'updatedAt',
        'name': 'name',
        'seller': 'seller'
    }

    def __init__(self, additional_services=None, created_at=None, id=None, updated_at=None, name=None, seller=None, local_vars_configuration=None):  # noqa: E501
        """AdditionalServicesGroupResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_services = None
        self._created_at = None
        self._id = None
        self._updated_at = None
        self._name = None
        self._seller = None
        self.discriminator = None

        if additional_services is not None:
            self.additional_services = additional_services
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if updated_at is not None:
            self.updated_at = updated_at
        if name is not None:
            self.name = name
        if seller is not None:
            self.seller = seller

    @property
    def additional_services(self):
        """Gets the additional_services of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The additional_services of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: list[AdditionalServiceResponse]
        """
        return self._additional_services

    @additional_services.setter
    def additional_services(self, additional_services):
        """Sets the additional_services of this AdditionalServicesGroupResponse.


        :param additional_services: The additional_services of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: list[AdditionalServiceResponse]
        """

        self._additional_services = additional_services

    @property
    def created_at(self):
        """Gets the created_at of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The created_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AdditionalServicesGroupResponse.


        :param created_at: The created_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The id of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AdditionalServicesGroupResponse.


        :param id: The id of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def updated_at(self):
        """Gets the updated_at of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The updated_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this AdditionalServicesGroupResponse.


        :param updated_at: The updated_at of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def name(self):
        """Gets the name of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The name of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AdditionalServicesGroupResponse.


        :param name: The name of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def seller(self):
        """Gets the seller of this AdditionalServicesGroupResponse.  # noqa: E501


        :return: The seller of this AdditionalServicesGroupResponse.  # noqa: E501
        :rtype: Reference
        """
        return self._seller

    @seller.setter
    def seller(self, seller):
        """Sets the seller of this AdditionalServicesGroupResponse.


        :param seller: The seller of this AdditionalServicesGroupResponse.  # noqa: E501
        :type: Reference
        """

        self._seller = seller

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdditionalServicesGroupResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdditionalServicesGroupResponse):
            return True

        return self.to_dict() != other.to_dict()
