# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.additional_services_groups import AdditionalServicesGroups  # noqa: E501
from allegro_api.rest import ApiException

class TestAdditionalServicesGroups(unittest.TestCase):
    """AdditionalServicesGroups unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdditionalServicesGroups
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.additional_services_groups.AdditionalServicesGroups()  # noqa: E501
        if include_optional :
            return AdditionalServicesGroups(
                additional_services_groups = [
                    allegro_api.models.additional_services_group_response.AdditionalServicesGroupResponse(
                        additional_services = [
                            allegro_api.models.additional_service_response.AdditionalServiceResponse(
                                configurations = [
                                    allegro_api.models.configuration.Configuration(
                                        constraints = allegro_api.models.constraint_criteria.ConstraintCriteria(
                                            country = '0', 
                                            type = 'COUNTRY_SAME_QUANTITY', 
                                            delivery_methods = [
                                                allegro_api.models.just_id.JustId(
                                                    id = '0', )
                                                ], ), 
                                        price = allegro_api.models.price.Price(
                                            amount = '123.45', 
                                            currency = 'PLN', ), )
                                    ], 
                                definition = allegro_api.models.basic_definition_response.BasicDefinitionResponse(
                                    id = '0', ), 
                                description = '0', )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '0', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        seller = allegro_api.models.reference.Reference(
                            id = '0', ), )
                    ]
            )
        else :
            return AdditionalServicesGroups(
        )

    def testAdditionalServicesGroups(self):
        """Test AdditionalServicesGroups"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
