# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class InlineResponse2001ShippingRatesConstraintsFirstItemRate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'min': 'str',
        'max': 'str',
        'currency': 'str'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'currency': 'currency'
    }

    def __init__(self, min=None, max=None, currency=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse2001ShippingRatesConstraintsFirstItemRate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._min = None
        self._max = None
        self._currency = None
        self.discriminator = None

        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        if currency is not None:
            self.currency = currency

    @property
    def min(self):
        """Gets the min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        Lower limit for the rate.  # noqa: E501

        :return: The min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        Lower limit for the rate.  # noqa: E501

        :param min: The min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                min is not None and len(min) > 15):
            raise ValueError("Invalid value for `min`, length must be less than or equal to `15`")  # noqa: E501

        self._min = min

    @property
    def max(self):
        """Gets the max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        Upper limit for the rate.  # noqa: E501

        :return: The max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        Upper limit for the rate.  # noqa: E501

        :param max: The max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                max is not None and len(max) > 15):
            raise ValueError("Invalid value for `max`, length must be less than or equal to `15`")  # noqa: E501

        self._max = max

    @property
    def currency(self):
        """Gets the currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        ISO 4217 currency code.  # noqa: E501

        :return: The currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        ISO 4217 currency code.  # noqa: E501

        :param currency: The currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001ShippingRatesConstraintsFirstItemRate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001ShippingRatesConstraintsFirstItemRate):
            return True

        return self.to_dict() != other.to_dict()
