# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.classified_package_configs import ClassifiedPackageConfigs  # noqa: E501
from allegro_api.rest import ApiException

class TestClassifiedPackageConfigs(unittest.TestCase):
    """ClassifiedPackageConfigs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClassifiedPackageConfigs
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.classified_package_configs.ClassifiedPackageConfigs()  # noqa: E501
        if include_optional :
            return ClassifiedPackageConfigs(
                packages = [
                    allegro_api.models.classified_package_config.ClassifiedPackageConfig(
                        extensions = [
                            allegro_api.models.classified_extension.ClassifiedExtension(
                                description = 'Autocentrum.pl', 
                                name = 'autocentrumExport', )
                            ], 
                        id = '6174be19-56f9-484b-b72c-43b0b00785e8', 
                        name = 'Power', 
                        promotions = [
                            allegro_api.models.classified_promotion.ClassifiedPromotion(
                                duration = 'PT240H', 
                                name = 'emphasized', )
                            ], 
                        publication = allegro_api.models.classified_publication.ClassifiedPublication(
                            duration = 'PT240H', ), 
                        type = 'BASE', )
                    ]
            )
        else :
            return ClassifiedPackageConfigs(
                packages = [
                    allegro_api.models.classified_package_config.ClassifiedPackageConfig(
                        extensions = [
                            allegro_api.models.classified_extension.ClassifiedExtension(
                                description = 'Autocentrum.pl', 
                                name = 'autocentrumExport', )
                            ], 
                        id = '6174be19-56f9-484b-b72c-43b0b00785e8', 
                        name = 'Power', 
                        promotions = [
                            allegro_api.models.classified_promotion.ClassifiedPromotion(
                                duration = 'PT240H', 
                                name = 'emphasized', )
                            ], 
                        publication = allegro_api.models.classified_publication.ClassifiedPublication(
                            duration = 'PT240H', ), 
                        type = 'BASE', )
                    ],
        )

    def testClassifiedPackageConfigs(self):
        """Test ClassifiedPackageConfigs"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
