# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.search_result import SearchResult  # noqa: E501
from allegro_api.rest import ApiException

class TestSearchResult(unittest.TestCase):
    """SearchResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SearchResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.search_result.SearchResult()  # noqa: E501
        if include_optional :
            return SearchResult(
                pos_list = [
                    allegro_api.models.pos.Pos(
                        id = '0', 
                        external_id = '0', 
                        name = '0', 
                        seller = allegro_api.models.seller.Seller(
                            id = '0', ), 
                        type = '0', 
                        address = allegro_api.models.address.Address(
                            street = '0', 
                            city = '0', 
                            zip_code = '0', 
                            state = '0', 
                            country_code = '0', 
                            coordinates = allegro_api.models.coordinates.Coordinates(
                                lat = 1.337, 
                                lon = 1.337, ), ), 
                        phone_number = '0', 
                        email = '0', 
                        open_hours = [
                            allegro_api.models.open_hour.OpenHour(
                                day_of_week = '0', 
                                from = '0', 
                                to = '0', )
                            ], 
                        service_time = '0', 
                        payments = [
                            allegro_api.models.payment.Payment(
                                method = '0', )
                            ], 
                        confirmation_type = '0', 
                        status = '0', 
                        created_at = '0', 
                        updated_at = '0', )
                    ]
            )
        else :
            return SearchResult(
        )

    def testSearchResult(self):
        """Test SearchResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
