# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.sale_product_dto import SaleProductDto  # noqa: E501
from allegro_api.rest import ApiException

class TestSaleProductDto(unittest.TestCase):
    """SaleProductDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SaleProductDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.sale_product_dto.SaleProductDto()  # noqa: E501
        if include_optional :
            return SaleProductDto(
                id = 'c9e39cae-9cb6-11e9-a2a3-2a2ae2dbcce4', 
                name = 'iPhone 5s', 
                category = allegro_api.models.category.Category(
                    id = '0', ), 
                eans = ["0019062113399","0000007905193"], 
                images = [
                    allegro_api.models.image_url.ImageUrl(
                        url = '0', )
                    ], 
                parameters = [
                    allegro_api.models.product_parameter.ProductParameter(
                        id = '0', 
                        range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                            from = '0', 
                            to = '0', ), 
                        values = [
                            '0'
                            ], 
                        values_ids = [
                            '0'
                            ], 
                        values_labels = [
                            '0'
                            ], 
                        unit = '0', 
                        options = [
                            allegro_api.models.product_parameter_options.ProductParameter_options(
                                identifies_product = True, )
                            ], )
                    ], 
                offer_requirements = allegro_api.models.offer_requirements.OfferRequirements(
                    parameters = [
                        allegro_api.models.product_parameter.ProductParameter(
                            id = '0', 
                            range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                from = '0', 
                                to = '0', ), 
                            values = [
                                '0'
                                ], 
                            values_ids = [
                                '0'
                                ], 
                            values_labels = [
                                '0'
                                ], 
                            unit = '0', 
                            options = [
                                allegro_api.models.product_parameter_options.ProductParameter_options(
                                    identifies_product = True, )
                                ], )
                        ], ), 
                compatibility_list = allegro_api.models.sale_product_compatibility_list.SaleProductCompatibilityList(
                    id = '460b2511-b786-47b9-9d7e-1f868728cfd6-f103931434fbf4aa06764f3df74d371df23aa138a9cd46dbe570f51af79db1c4-2', 
                    type = 'PRODUCT_BASED', 
                    items = [
                        allegro_api.models.compatibility_list_item_product_based.CompatibilityListItemProductBased(
                            text = 'AUDI 90 (89, 89Q, 8A, B3) 1988/06-1991/09 2.3 E 20V quattro 170KM/125kW 1501', )
                        ], ), 
                tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                    id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', 
                    items = [
                        allegro_api.models.tecdoc_specification_item.TecdocSpecificationItem(
                            name = 'Wersja TecDoc', 
                            values = ["0319"], )
                        ], ), 
                description = allegro_api.models.standardized_description.StandardizedDescription(
                    sections = [
                        allegro_api.models.description_section.DescriptionSection(
                            items = [
                                allegro_api.models.description_section_item.DescriptionSectionItem(
                                    type = '0', )
                                ], )
                        ], )
            )
        else :
            return SaleProductDto(
                id = 'c9e39cae-9cb6-11e9-a2a3-2a2ae2dbcce4',
                name = 'iPhone 5s',
                category = allegro_api.models.category.Category(
                    id = '0', ),
        )

    def testSaleProductDto(self):
        """Test SaleProductDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
