# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.payment_operations import PaymentOperations  # noqa: E501
from allegro_api.rest import ApiException

class TestPaymentOperations(unittest.TestCase):
    """PaymentOperations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaymentOperations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.payment_operations.PaymentOperations()  # noqa: E501
        if include_optional :
            return PaymentOperations(
                payment_operations = [
                    allegro_api.models.base_operation.BaseOperation(
                        type = '0', 
                        group = 'INCOME', 
                        wallet = allegro_api.models.wallet.Wallet(
                            payment_operator = 'PAYU', 
                            type = 'AVAILABLE', 
                            balance = null, ), 
                        value = null, 
                        occurred_at = '2019-05-08T09:45:00.818Z', )
                    ], 
                count = 50, 
                total_count = 123
            )
        else :
            return PaymentOperations(
                payment_operations = [
                    allegro_api.models.base_operation.BaseOperation(
                        type = '0', 
                        group = 'INCOME', 
                        wallet = allegro_api.models.wallet.Wallet(
                            payment_operator = 'PAYU', 
                            type = 'AVAILABLE', 
                            balance = null, ), 
                        value = null, 
                        occurred_at = '2019-05-08T09:45:00.818Z', )
                    ],
                count = 50,
                total_count = 123,
        )

    def testPaymentOperations(self):
        """Test PaymentOperations"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
