# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.after_sale_services_api import AfterSaleServicesApi  # noqa: E501
from allegro_api.rest import ApiException


class TestAfterSaleServicesApi(unittest.TestCase):
    """AfterSaleServicesApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.after_sale_services_api.AfterSaleServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_public_seller_listing_using_get(self):
        """Test case for get_public_seller_listing_using_get

        Get the user's implied warranties  # noqa: E501
        """
        pass

    def test_get_public_seller_listing_using_get1(self):
        """Test case for get_public_seller_listing_using_get1

        Get the user's return policies  # noqa: E501
        """
        pass

    def test_get_public_seller_listing_using_get2(self):
        """Test case for get_public_seller_listing_using_get2

        Get the user's warranties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
