# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.order_management_api import OrderManagementApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOrderManagementApi(unittest.TestCase):
    """OrderManagementApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.order_management_api.OrderManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_order_shipments_using_post(self):
        """Test case for create_order_shipments_using_post

        Add a parcel tracking number  # noqa: E501
        """
        pass

    def test_find_mapping(self):
        """Test case for find_mapping

        Get mapping for line item id  # noqa: E501
        """
        pass

    def test_get_list_of_orders_using_get(self):
        """Test case for get_list_of_orders_using_get

        Get the user's orders  # noqa: E501
        """
        pass

    def test_get_order_events_statistics_using_get(self):
        """Test case for get_order_events_statistics_using_get

        Get order events statistics  # noqa: E501
        """
        pass

    def test_get_order_events_using_get(self):
        """Test case for get_order_events_using_get

        Get order events  # noqa: E501
        """
        pass

    def test_get_order_shipments_using_get(self):
        """Test case for get_order_shipments_using_get

        Get a list of parcel tracking numbers  # noqa: E501
        """
        pass

    def test_get_orders_details_using_get(self):
        """Test case for get_orders_details_using_get

        Get an order's details  # noqa: E501
        """
        pass

    def test_set_order_fulfillment_using_put(self):
        """Test case for set_order_fulfillment_using_put

        Set seller order status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
