# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.categories_dto import CategoriesDto  # noqa: E501
from allegro_api.rest import ApiException

class TestCategoriesDto(unittest.TestCase):
    """CategoriesDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CategoriesDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.categories_dto.CategoriesDto()  # noqa: E501
        if include_optional :
            return CategoriesDto(
                categories = [
                    allegro_api.models.category_dto.CategoryDto(
                        id = '12', 
                        leaf = True, 
                        name = 'Pozostałe', 
                        options = allegro_api.models.category_options_dto.CategoryOptionsDto(
                            advertisement = True, 
                            advertisement_price_optional = True, 
                            variants_by_color_pattern_allowed = True, 
                            offers_with_product_publication_enabled = True, 
                            product_creation_enabled = True, 
                            product_ean_required = True, ), 
                        parent = allegro_api.models.category_dto_parent.CategoryDto_parent(
                            id = '709', ), )
                    ]
            )
        else :
            return CategoriesDto(
        )

    def testCategoriesDto(self):
        """Test CategoriesDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
