# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.pricing_api import PricingApi  # noqa: E501
from allegro_api.rest import ApiException


class TestPricingApi(unittest.TestCase):
    """PricingApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.pricing_api.PricingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_calculate_fee_preview_using_post(self):
        """Test case for calculate_fee_preview_using_post

        Calculate fee and commission for an offer  # noqa: E501
        """
        pass

    def test_offer_quotes_public_using_get(self):
        """Test case for offer_quotes_public_using_get

        Get the user's current offer quotes  # noqa: E501
        """
        pass

    def test_preview_fees_public_api_using_post(self):
        """Test case for preview_fees_public_api_using_post

        Preview offer fees  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
