# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.delivery_api import DeliveryApi  # noqa: E501
from allegro_api.rest import ApiException


class TestDeliveryApi(unittest.TestCase):
    """DeliveryApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.delivery_api.DeliveryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_shipping_rates_set_using_post(self):
        """Test case for create_shipping_rates_set_using_post

        Create a new shipping rates set  # noqa: E501
        """
        pass

    def test_get_list_of_delivery_methods_using_get(self):
        """Test case for get_list_of_delivery_methods_using_get

        Get the list of delivery methods  # noqa: E501
        """
        pass

    def test_get_list_of_shipping_ratest_using_get(self):
        """Test case for get_list_of_shipping_ratest_using_get

        Get the user's shipping rates  # noqa: E501
        """
        pass

    def test_get_offer_shipping_rates_get(self):
        """Test case for get_offer_shipping_rates_get

        [BETA] Get shipping rates assigned to an offer  # noqa: E501
        """
        pass

    def test_get_sale_delivery_settings(self):
        """Test case for get_sale_delivery_settings

        Get the user's delivery settings  # noqa: E501
        """
        pass

    def test_get_shipping_rates_set_using_get(self):
        """Test case for get_shipping_rates_set_using_get

        Get the details of a shipping rates set  # noqa: E501
        """
        pass

    def test_modify_shipping_rates_set_using_put(self):
        """Test case for modify_shipping_rates_set_using_put

        Edit a user's shipping rates set  # noqa: E501
        """
        pass

    def test_put_sale_delivery_settings(self):
        """Test case for put_sale_delivery_settings

        Modify the user's delivery settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
