# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_rating import OfferRating  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferRating(unittest.TestCase):
    """OfferRating unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferRating
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_rating.OfferRating()  # noqa: E501
        if include_optional :
            return OfferRating(
                average_score = '4.0', 
                score_distribution = [{"name":"5","count":1},{"name":"4","count":3},{"name":"3","count":1},{"name":"2","count":0},{"name":"1","count":0}], 
                total_responses = 5, 
                size_feedback = [{"name":"BIGGER","count":0},{"name":"FIT","count":2},{"name":"SMALLER","count":0}]
            )
        else :
            return OfferRating(
        )

    def testOfferRating(self):
        """Test OfferRating"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
