# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.disputes_api import DisputesApi  # noqa: E501
from allegro_api.rest import ApiException


class TestDisputesApi(unittest.TestCase):
    """DisputesApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.disputes_api.DisputesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_message_to_dispute_using_post(self):
        """Test case for add_message_to_dispute_using_post

        Add a message to a dispute  # noqa: E501
        """
        pass

    def test_create_an_attachment_using_post(self):
        """Test case for create_an_attachment_using_post

        Create an attachment declaration  # noqa: E501
        """
        pass

    def test_get_attachment_using_get(self):
        """Test case for get_attachment_using_get

        Get an attachment  # noqa: E501
        """
        pass

    def test_get_dispute_using_get(self):
        """Test case for get_dispute_using_get

        Get a single dispute  # noqa: E501
        """
        pass

    def test_get_list_of_disputes_using_get(self):
        """Test case for get_list_of_disputes_using_get

        Get the user's disputes  # noqa: E501
        """
        pass

    def test_get_messages_from_dispute_using_get(self):
        """Test case for get_messages_from_dispute_using_get

        Get the messages within a dispute  # noqa: E501
        """
        pass

    def test_upload_dispute_attachment_using_put(self):
        """Test case for upload_dispute_attachment_using_put

        Upload a dispute message attachment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
