# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.products_api import ProductsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.products_api.ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_flat_product_parameters_using_get(self):
        """Test case for get_flat_product_parameters_using_get

        Get product parameters available in given category  # noqa: E501
        """
        pass

    def test_get_sale_product(self):
        """Test case for get_sale_product

        Get all data of the particular product  # noqa: E501
        """
        pass

    def test_get_sale_products(self):
        """Test case for get_sale_products

        Get search products results  # noqa: E501
        """
        pass

    def test_propose_sale_product(self):
        """Test case for propose_sale_product

        Propose a product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
