# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.compatibility_list_id_item_all_of import CompatibilityListIdItemAllOf  # noqa: E501
from allegro_api.rest import ApiException

class TestCompatibilityListIdItemAllOf(unittest.TestCase):
    """CompatibilityListIdItemAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CompatibilityListIdItemAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.compatibility_list_id_item_all_of.CompatibilityListIdItemAllOf()  # noqa: E501
        if include_optional :
            return CompatibilityListIdItemAllOf(
                type = 'ID', 
                id = '0006563f-f2b9-44ea-ae67-4678679be1f1', 
                text = 'CITROËN C6 (TD_) 2005/09-2011/12 2.7 HDi 204KM/150kW', 
                additional_info = [
                    allegro_api.models.compatibility_list_id_item_additional_info.CompatibilityListIdItemAdditionalInfo(
                        value = 'only for versions with BDX engine code', )
                    ]
            )
        else :
            return CompatibilityListIdItemAllOf(
                id = '0006563f-f2b9-44ea-ae67-4678679be1f1',
        )

    def testCompatibilityListIdItemAllOf(self):
        """Test CompatibilityListIdItemAllOf"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
