# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.offer_tags_api import OfferTagsApi  # noqa: E501
from allegro_api.rest import ApiException


class TestOfferTagsApi(unittest.TestCase):
    """OfferTagsApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.offer_tags_api.OfferTagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_assign_tag_to_offer_post(self):
        """Test case for assign_tag_to_offer_post

        Assign tags to an offer  # noqa: E501
        """
        pass

    def test_create_tag_post1(self):
        """Test case for create_tag_post1

        Create a tag  # noqa: E501
        """
        pass

    def test_delete_tag_using_delete(self):
        """Test case for delete_tag_using_delete

        Delete a tag  # noqa: E501
        """
        pass

    def test_list_assigned_offer_tags_get(self):
        """Test case for list_assigned_offer_tags_get

        Get tags assigned to an offer  # noqa: E501
        """
        pass

    def test_list_seller_tags_get1(self):
        """Test case for list_seller_tags_get1

        Get the user's tags  # noqa: E501
        """
        pass

    def test_update_tag_put(self):
        """Test case for update_tag_put

        Modify a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
