# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.dispute_list_response import DisputeListResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestDisputeListResponse(unittest.TestCase):
    """DisputeListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DisputeListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.dispute_list_response.DisputeListResponse()  # noqa: E501
        if include_optional :
            return DisputeListResponse(
                disputes = [
                    allegro_api.models.dispute.Dispute(
                        id = '0', 
                        subject = allegro_api.models.subject.Subject(
                            name = 'nie otrzymałem towaru po wpłacie', ), 
                        status = 'CLOSED', 
                        buyer = allegro_api.models.dispute_user.DisputeUser(
                            id = '0', 
                            login = '0', ), 
                        seller = allegro_api.models.dispute_user.DisputeUser(
                            id = '0', 
                            login = '0', ), 
                        checkout_form = allegro_api.models.dispute_checkout_form.DisputeCheckoutForm(
                            id = '0', 
                            created_at = '2018-02-10T12:12:12Z', ), 
                        message = allegro_api.models.dispute_first_message.DisputeFirstMessage(
                            id = '0', 
                            text = '0', 
                            attachment = allegro_api.models.dispute_attachment.DisputeAttachment(
                                file_name = '0', 
                                url = 'https://upload.allegro.pl/sale/dispute-attachments/eeed0007-4404-4176-a1eb-11d26f056c0d', ), 
                            author = allegro_api.models.dispute_author.DisputeAuthor(
                                login = '0', 
                                role = 'BUYER', ), 
                            created_at = '2018-02-10T12:12:12Z', ), 
                        messages_count = 56, )
                    ]
            )
        else :
            return DisputeListResponse(
        )

    def testDisputeListResponse(self):
        """Test DisputeListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
