# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.categories_and_parameters_api import CategoriesAndParametersApi  # noqa: E501
from allegro_api.rest import ApiException


class TestCategoriesAndParametersApi(unittest.TestCase):
    """CategoriesAndParametersApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.categories_and_parameters_api.CategoriesAndParametersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_categories_using_get(self):
        """Test case for get_categories_using_get

        Get IDs of Allegro categories  # noqa: E501
        """
        pass

    def test_get_category_using_get1(self):
        """Test case for get_category_using_get1

        Get a category by ID  # noqa: E501
        """
        pass

    def test_get_flat_parameters_using_get2(self):
        """Test case for get_flat_parameters_using_get2

        Get parameters supported by a category  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
