# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_form_delivery_reference import CheckoutFormDeliveryReference  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutFormDeliveryReference(unittest.TestCase):
    """CheckoutFormDeliveryReference unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutFormDeliveryReference
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_form_delivery_reference.CheckoutFormDeliveryReference()  # noqa: E501
        if include_optional :
            return CheckoutFormDeliveryReference(
                address = allegro_api.models.checkout_form_delivery_address.CheckoutFormDeliveryAddress(
                    first_name = 'Jan', 
                    last_name = 'Kowalski', 
                    street = 'Grunwaldzka 182', 
                    city = 'Poznań', 
                    zip_code = '60-166', 
                    country_code = 'PL', 
                    company_name = '0', 
                    phone_number = '0', ), 
                method = allegro_api.models.checkout_form_delivery_method.CheckoutFormDeliveryMethod(
                    id = '1fa56f79-4b6a-4821-a6f2-ca9c16d5c925', 
                    name = 'Allegro Paczkomaty InPost', ), 
                pickup_point = allegro_api.models.checkout_form_delivery_pickup_point.CheckoutFormDeliveryPickupPoint(
                    id = 'POZ08A', 
                    name = 'Paczkomat POZ08A', 
                    description = 'Stacja paliw BP', 
                    address = allegro_api.models.checkout_form_delivery_pickup_point_address.CheckoutFormDeliveryPickupPointAddress(
                        street = 'Grunwaldzka 108', 
                        zip_code = '60-166', 
                        city = 'Poznań', ), ), 
                cost = allegro_api.models.price.Price(
                    amount = '123.45', 
                    currency = 'PLN', ), 
                time = allegro_api.models.checkout_form_delivery_time.CheckoutFormDeliveryTime(
                    guaranteed = allegro_api.models.checkout_form_delivery_time_guaranteed.CheckoutFormDeliveryTimeGuaranteed(
                        from = '2018-01-01T16:00Z', 
                        to = '2018-01-01T18:00Z', ), ), 
                smart = True, 
                calculated_number_of_packages = 1
            )
        else :
            return CheckoutFormDeliveryReference(
        )

    def testCheckoutFormDeliveryReference(self):
        """Test CheckoutFormDeliveryReference"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
