# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferListingDtoV1Publication(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'OfferStatus',
        'starting_at': 'str',
        'started_at': 'str',
        'ending_at': 'str',
        'ended_at': 'str'
    }

    attribute_map = {
        'status': 'status',
        'starting_at': 'startingAt',
        'started_at': 'startedAt',
        'ending_at': 'endingAt',
        'ended_at': 'endedAt'
    }

    def __init__(self, status=None, starting_at=None, started_at=None, ending_at=None, ended_at=None, local_vars_configuration=None):  # noqa: E501
        """OfferListingDtoV1Publication - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._starting_at = None
        self._started_at = None
        self._ending_at = None
        self._ended_at = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if starting_at is not None:
            self.starting_at = starting_at
        if started_at is not None:
            self.started_at = started_at
        if ending_at is not None:
            self.ending_at = ending_at
        if ended_at is not None:
            self.ended_at = ended_at

    @property
    def status(self):
        """Gets the status of this OfferListingDtoV1Publication.  # noqa: E501


        :return: The status of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: OfferStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OfferListingDtoV1Publication.


        :param status: The status of this OfferListingDtoV1Publication.  # noqa: E501
        :type: OfferStatus
        """

        self._status = status

    @property
    def starting_at(self):
        """Gets the starting_at of this OfferListingDtoV1Publication.  # noqa: E501

        The date and time of activation in UTC for a planned listing.  # noqa: E501

        :return: The starting_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._starting_at

    @starting_at.setter
    def starting_at(self, starting_at):
        """Sets the starting_at of this OfferListingDtoV1Publication.

        The date and time of activation in UTC for a planned listing.  # noqa: E501

        :param starting_at: The starting_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._starting_at = starting_at

    @property
    def started_at(self):
        """Gets the started_at of this OfferListingDtoV1Publication.  # noqa: E501

        The actual date and time of activation in UTC.  # noqa: E501

        :return: The started_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this OfferListingDtoV1Publication.

        The actual date and time of activation in UTC.  # noqa: E501

        :param started_at: The started_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._started_at = started_at

    @property
    def ending_at(self):
        """Gets the ending_at of this OfferListingDtoV1Publication.  # noqa: E501

        The date and time of a planned ending in UTC.  # noqa: E501

        :return: The ending_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._ending_at

    @ending_at.setter
    def ending_at(self, ending_at):
        """Sets the ending_at of this OfferListingDtoV1Publication.

        The date and time of a planned ending in UTC.  # noqa: E501

        :param ending_at: The ending_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._ending_at = ending_at

    @property
    def ended_at(self):
        """Gets the ended_at of this OfferListingDtoV1Publication.  # noqa: E501

        The actual date and time of last ending in UTC.  # noqa: E501

        :return: The ended_at of this OfferListingDtoV1Publication.  # noqa: E501
        :rtype: str
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this OfferListingDtoV1Publication.

        The actual date and time of last ending in UTC.  # noqa: E501

        :param ended_at: The ended_at of this OfferListingDtoV1Publication.  # noqa: E501
        :type: str
        """

        self._ended_at = ended_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferListingDtoV1Publication):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferListingDtoV1Publication):
            return True

        return self.to_dict() != other.to_dict()
