# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.inline_response2001 import InlineResponse2001  # noqa: E501
from allegro_api.rest import ApiException

class TestInlineResponse2001(unittest.TestCase):
    """InlineResponse2001 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse2001
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.inline_response2001.InlineResponse2001()  # noqa: E501
        if include_optional :
            return InlineResponse2001(
                delivery_methods = [
                    allegro_api.models.inline_response_200_1_delivery_methods.inline_response_200_1_deliveryMethods(
                        id = '0', 
                        name = '0', 
                        payment_policy = 'IN_ADVANCE', 
                        allegro_endorsed = True, 
                        shipping_rates_constraints = allegro_api.models.inline_response_200_1_shipping_rates_constraints.inline_response_200_1_shippingRatesConstraints(
                            allowed = True, 
                            max_quantity_per_package = allegro_api.models.inline_response_200_1_shipping_rates_constraints_max_quantity_per_package.inline_response_200_1_shippingRatesConstraints_maxQuantityPerPackage(
                                max = 999999, ), 
                            first_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_first_item_rate.inline_response_200_1_shippingRatesConstraints_firstItemRate(
                                min = '0.00', 
                                max = '8.99', 
                                currency = 'PLN', ), 
                            next_item_rate = allegro_api.models.inline_response_200_1_shipping_rates_constraints_next_item_rate.inline_response_200_1_shippingRatesConstraints_nextItemRate(
                                min = '0.00', 
                                max = '8.99', 
                                currency = 'PLN', ), 
                            shipping_time = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time.inline_response_200_1_shippingRatesConstraints_shippingTime(
                                default = allegro_api.models.inline_response_200_1_shipping_rates_constraints_shipping_time_default.inline_response_200_1_shippingRatesConstraints_shippingTime_default(
                                    from = 'PT24H', 
                                    to = 'PT48H', ), 
                                customizable = True, ), ), )
                    ]
            )
        else :
            return InlineResponse2001(
        )

    def testInlineResponse2001(self):
        """Test InlineResponse2001"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
